Exception: WaveFile::InvalidFormatError
- Inherits:
-
StandardError
- Object
- StandardError
- WaveFile::InvalidFormatError
- Defined in:
- lib/wavefile/reader.rb,
lib/wavefile/format.rb
Overview
Error that is raised when trying to read from a file that is either not a wave file, or that is not valid according to the wave file spec.