Method: WaveFile::Reader#format

Defined in:
lib/wavefile/reader.rb

#formatObject

Public: Returns an object describing how sample data is being read from the Wave file. I.e., number of channels, bits per sample, sample format, etc. If #readable_format? is true, then this will be a Format object. The format the samples are read out as might be different from how the samples are actually stored in the file. Therefore, #format might not match #native_format. If #readable_format? is false, then this will return the same value as #native_format.



188
189
190
# File 'lib/wavefile/reader.rb', line 188

def format
  @data_chunk_reader.format
end